@@ -9,7 +9,7 @@
 @Desciption :   None
 """
 
-from cylinder_qrcode_project.cqrcode.view.GUI_welcome import hello
+from cqrcode.view.GUI_welcome import hello
 
 while True:
     x = input('请输入 s 启动...\n')
